@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -356,7 +356,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
     def create_environment(
         self,
-        request: environments.CreateEnvironmentRequest = None,
+        request: Union[environments.CreateEnvironmentRequest, dict] = None,
         *,
         parent: str = None,
         environment: environments.Environment = None,
@@ -367,7 +367,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         r"""Create a new environment.
 
         Args:
-            request (google.cloud.orchestration.airflow.service_v1.types.CreateEnvironmentRequest):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.CreateEnvironmentRequest, dict]):
                 The request object. Create a new environment.
             parent (str):
                 The parent must be of the form
@@ -445,7 +445,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
     def get_environment(
         self,
-        request: environments.GetEnvironmentRequest = None,
+        request: Union[environments.GetEnvironmentRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -455,7 +455,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         r"""Get an existing environment.
 
         Args:
-            request (google.cloud.orchestration.airflow.service_v1.types.GetEnvironmentRequest):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.GetEnvironmentRequest, dict]):
                 The request object. Get an environment.
             name (str):
                 The resource name of the environment
@@ -516,7 +516,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
     def list_environments(
         self,
-        request: environments.ListEnvironmentsRequest = None,
+        request: Union[environments.ListEnvironmentsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -526,7 +526,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         r"""List environments.
 
         Args:
-            request (google.cloud.orchestration.airflow.service_v1.types.ListEnvironmentsRequest):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.ListEnvironmentsRequest, dict]):
                 The request object. List environments in a project and
                 location.
             parent (str):
@@ -597,7 +597,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
     def update_environment(
         self,
-        request: environments.UpdateEnvironmentRequest = None,
+        request: Union[environments.UpdateEnvironmentRequest, dict] = None,
         *,
         name: str = None,
         environment: environments.Environment = None,
@@ -609,7 +609,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         r"""Update an environment.
 
         Args:
-            request (google.cloud.orchestration.airflow.service_v1.types.UpdateEnvironmentRequest):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.UpdateEnvironmentRequest, dict]):
                 The request object. Update an environment.
             name (str):
                 The relative resource name of the
@@ -860,7 +860,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
 
     def delete_environment(
         self,
-        request: environments.DeleteEnvironmentRequest = None,
+        request: Union[environments.DeleteEnvironmentRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -870,7 +870,7 @@ class EnvironmentsClient(metaclass=EnvironmentsClientMeta):
         r"""Delete an environment.
 
         Args:
-            request (google.cloud.orchestration.airflow.service_v1.types.DeleteEnvironmentRequest):
+            request (Union[google.cloud.orchestration.airflow.service_v1.types.DeleteEnvironmentRequest, dict]):
                 The request object. Delete an environment.
             name (str):
                 The environment to delete, in the
